Skip to contents

Sticky flags accumulate the signals raised by operations that were not trapped (see decimal_context()). They persist until clear_decimal_flags() is called. By default the same non-trapped signals are also reported as warnings as they occur; set options(decimal.report_flags = FALSE) to silence the warnings and inspect flags only through this function.

Usage

decimal_flags()

Value

A character vector of active sticky flags.

Examples

decimal_flags()
#> character(0)