fma() computes x * y + z with a single final rounding step. This can be
more accurate than evaluating multiplication and addition separately under
a limited-precision context. The arguments follow normal vctrs recycling
rules.
fma() computes x * y + z with a single final rounding step. This can be
more accurate than evaluating multiplication and addition separately under
a limited-precision context. The arguments follow normal vctrs recycling
rules.