Skip to contents

is_decimal() reports whether x inherits from the decimal vector class. It does not attempt to parse or convert other objects.

Usage

is_decimal(x)

Arguments

x

An object to test.

Value

A single logical value.

Examples

is_decimal(decimal("1.5"))
#> [1] TRUE