R/decimal.R
is_qnan.Rd
is_qnan() identifies quiet not-a-number values. Signaling NaNs and R missing values are not quiet NaNs.
is_qnan()
is_qnan(x)
A decimal-compatible vector.
A logical vector with the same length as x.
x
is_qnan(decimal(c("NaN", "sNaN", "1"))) #> [1] TRUE FALSE FALSE