Skip to contents

Returns the version string reported by the bundled mpdecimal library that was loaded with the package DLL.

Usage

mpdecimal_version()

Value

A length-one character vector.

Examples

mpdecimal_version()
#> [1] "4.0.1"