is_decimal() reports whether x inherits from the decimal vector
class. It does not attempt to parse or convert other objects.
Examples
is_decimal(decimal("1.5"))
#> [1] TRUE
is_decimal() reports whether x inherits from the decimal vector
class. It does not attempt to parse or convert other objects.
is_decimal(decimal("1.5"))
#> [1] TRUE