R/decimal.R
is_signed.Rd
is_signed() inspects the stored sign bit rather than comparing with zero. It therefore identifies negative zero as signed.
is_signed()
is_signed(x)
A decimal-compatible vector.
A logical vector with the same length as x.
x
is_signed(decimal(c("-2", "2", "-0", "0"))) #> [1] TRUE FALSE TRUE FALSE