R/decimal.R
is_zero.Rd
is_zero() identifies both positive and negative zero, regardless of the vector's scale.
is_zero()
is_zero(x)
A decimal-compatible vector.
A logical vector with the same length as x.
x
is_zero(decimal(c("0.00", "-0", "1"))) #> [1] TRUE TRUE FALSE