R/mpdecimal-version.R
mpdecimal_version.Rd
Returns the version string reported by the bundled mpdecimal library that was loaded with the package DLL.
mpdecimal
mpdecimal_version()
A length-one character vector.
mpdecimal_version() #> [1] "4.0.1"